@@ -73,12 +73,12 @@ public:
     , mMode(Contains)
     {}
 
-    bool needsSemanticInfo() const Q_DECL_OVERRIDE
+    bool needsSemanticInfo() const override
     {
         return false;
     }
 
-    bool acceptsIndex(const QModelIndex& index) const Q_DECL_OVERRIDE
+    bool acceptsIndex(const QModelIndex& index) const override
     {
         if (mText.isEmpty()) {
             return true;
@@ -113,7 +113,7 @@ class NameFilterWidget : public QWidget
     Q_OBJECT
 public:
     NameFilterWidget(SortedDirModel*);
-    ~NameFilterWidget();
+    ~NameFilterWidget() override;
 
 private Q_SLOTS:
     void applyNameFilter();
@@ -141,12 +141,12 @@ public:
     , mMode(GreaterOrEqual)
     {}
 
-    bool needsSemanticInfo() const Q_DECL_OVERRIDE
+    bool needsSemanticInfo() const override
     {
         return false;
     }
 
-    bool acceptsIndex(const QModelIndex& index) const Q_DECL_OVERRIDE
+    bool acceptsIndex(const QModelIndex& index) const override
     {
         if (!mDate.isValid()) {
             return true;
@@ -185,7 +185,7 @@ class DateFilterWidget : public QWidget
     Q_OBJECT
 public:
     DateFilterWidget(SortedDirModel*);
-    ~DateFilterWidget();
+    ~DateFilterWidget() override;
 
 private Q_SLOTS:
     void applyDateFilter();
@@ -215,12 +215,12 @@ public:
     , mRating(0)
     , mMode(GreaterOrEqual) {}
 
-    bool needsSemanticInfo() const Q_DECL_OVERRIDE
+    bool needsSemanticInfo() const override
     {
         return true;
     }
 
-    bool acceptsIndex(const QModelIndex& index) const Q_DECL_OVERRIDE
+    bool acceptsIndex(const QModelIndex& index) const override
     {
         SemanticInfo info = model()->semanticInfoForSourceIndex(index);
         switch (mMode) {
@@ -255,7 +255,7 @@ class RatingFilterWidget : public QWidget
     Q_OBJECT
 public:
     RatingFilterWidget(SortedDirModel*);
-    ~RatingFilterWidget();
+    ~RatingFilterWidget() override;
 
 private Q_SLOTS:
     void slotRatingChanged(int value);
@@ -278,12 +278,12 @@ public:
     , mWantMatchingTag(true)
     {}
 
-    bool needsSemanticInfo() const Q_DECL_OVERRIDE
+    bool needsSemanticInfo() const override
     {
         return true;
     }
 
-    bool acceptsIndex(const QModelIndex& index) const Q_DECL_OVERRIDE
+    bool acceptsIndex(const QModelIndex& index) const override
     {
         if (mTag.isEmpty()) {
             return true;
@@ -318,7 +318,7 @@ class TagFilterWidget : public QWidget
     Q_OBJECT
 public:
     TagFilterWidget(SortedDirModel*);
-    ~TagFilterWidget();
+    ~TagFilterWidget() override;
 
 private Q_SLOTS:
     void updateTagSetFilter();
