@@ -63,15 +63,15 @@ public:
         : AbstractThumbnailViewHelper(parent)
     {}
 
-    void showContextMenu(QWidget*) Q_DECL_OVERRIDE
+    void showContextMenu(QWidget*) override
     {
     }
 
-    void showMenuForUrlDroppedOnViewport(QWidget*, const QList<QUrl>&) Q_DECL_OVERRIDE
+    void showMenuForUrlDroppedOnViewport(QWidget*, const QList<QUrl>&) override
     {
     }
 
-    void showMenuForUrlDroppedOnDir(QWidget*, const QList<QUrl>&, const QUrl&) Q_DECL_OVERRIDE
+    void showMenuForUrlDroppedOnDir(QWidget*, const QList<QUrl>&, const QUrl&) override
     {
     }
 };
