@@ -413,7 +413,7 @@ struct PreviewItemDelegatePrivate
             QSize fullSize;
             QPixmap thumbnailPix = mView->thumbnailForIndex(index, &fullSize);
             if (fullSize.isValid()) {
-                const QString text = QString("%1x%2").arg(fullSize.width()).arg(fullSize.height());
+                const QString text = QStringLiteral("%1x%2").arg(fullSize.width()).arg(fullSize.height());
                 elided |= isTextElided(text);
                 textList << text;
             }
@@ -437,7 +437,7 @@ struct PreviewItemDelegatePrivate
         if (!mToolTip) {
             initToolTip();
         }
-        mToolTip->setText(textList.join("\n"));
+        mToolTip->setText(textList.join(QLatin1Char('\n')));
         QSize tipSize = mToolTip->sizeHint();
 
         // Compute tip position
@@ -542,7 +542,7 @@ struct PreviewItemDelegatePrivate
     void updateToggleSelectionButton()
     {
         mToggleSelectionButton->setIcon(QIcon::fromTheme(
-                                            mView->selectionModel()->isSelected(mIndexUnderCursor) ? "list-remove" : "list-add"
+                                            mView->selectionModel()->isSelected(mIndexUnderCursor) ? QStringLiteral("list-remove") : QStringLiteral("list-add")
                                         ));
     }
 
@@ -618,19 +618,19 @@ PreviewItemDelegate::PreviewItemDelegate(ThumbnailView* view)
     d->mContextBar->hide();
 
     d->mToggleSelectionButton = new QToolButton;
-    d->mToggleSelectionButton->setIcon(QIcon::fromTheme("list-add"));
+    d->mToggleSelectionButton->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
     connect(d->mToggleSelectionButton, &QToolButton::clicked, this, &PreviewItemDelegate::slotToggleSelectionClicked);
 
     d->mFullScreenButton = new QToolButton;
-    d->mFullScreenButton->setIcon(QIcon::fromTheme("view-fullscreen"));
+    d->mFullScreenButton->setIcon(QIcon::fromTheme(QStringLiteral("view-fullscreen")));
     connect(d->mFullScreenButton, &QToolButton::clicked, this, &PreviewItemDelegate::slotFullScreenClicked);
 
     d->mRotateLeftButton = new QToolButton;
-    d->mRotateLeftButton->setIcon(QIcon::fromTheme("object-rotate-left"));
+    d->mRotateLeftButton->setIcon(QIcon::fromTheme(QStringLiteral("object-rotate-left")));
     connect(d->mRotateLeftButton, &QToolButton::clicked, this, &PreviewItemDelegate::slotRotateLeftClicked);
 
     d->mRotateRightButton = new QToolButton;
-    d->mRotateRightButton->setIcon(QIcon::fromTheme("object-rotate-right"));
+    d->mRotateRightButton->setIcon(QIcon::fromTheme(QStringLiteral("object-rotate-right")));
     connect(d->mRotateRightButton, &QToolButton::clicked, this, &PreviewItemDelegate::slotRotateRightClicked);
 
     QHBoxLayout* layout = new QHBoxLayout(d->mContextBar);
@@ -643,7 +643,7 @@ PreviewItemDelegate::PreviewItemDelegate(ThumbnailView* view)
 
     // Save button
     d->mSaveButton = new QToolButton(d->mView->viewport());
-    d->mSaveButton->setIcon(QIcon::fromTheme("document-save"));
+    d->mSaveButton->setIcon(QIcon::fromTheme(QStringLiteral("document-save")));
     d->mSaveButton->hide();
     connect(d->mSaveButton, &QToolButton::clicked, this, &PreviewItemDelegate::slotSaveClicked);
 }
@@ -826,7 +826,7 @@ void PreviewItemDelegate::paint(QPainter * painter, const QStyleOptionViewItem &
 
     if (!isDirOrArchive && (d->mDetails & PreviewItemDelegate::ImageSizeDetail)) {
         if (fullSize.isValid()) {
-            const QString text = QString("%1x%2").arg(fullSize.width()).arg(fullSize.height());
+            const QString text = QStringLiteral("%1x%2").arg(fullSize.width()).arg(fullSize.height());
             d->drawText(painter, textRect, fgColor, text);
             textRect.moveTop(textRect.bottom());
         }
@@ -864,24 +864,24 @@ void PreviewItemDelegate::setThumbnailSize(const QSize& value)
 
 void PreviewItemDelegate::slotSaveClicked()
 {
-    saveDocumentRequested(urlForIndex(d->mIndexUnderCursor));
+    emit saveDocumentRequested(urlForIndex(d->mIndexUnderCursor));
 }
 
 void PreviewItemDelegate::slotRotateLeftClicked()
 {
     d->selectIndexUnderCursorIfNoMultiSelection();
-    rotateDocumentLeftRequested(urlForIndex(d->mIndexUnderCursor));
+    emit rotateDocumentLeftRequested(urlForIndex(d->mIndexUnderCursor));
 }
 
 void PreviewItemDelegate::slotRotateRightClicked()
 {
     d->selectIndexUnderCursorIfNoMultiSelection();
-    rotateDocumentRightRequested(urlForIndex(d->mIndexUnderCursor));
+    emit rotateDocumentRightRequested(urlForIndex(d->mIndexUnderCursor));
 }
 
 void PreviewItemDelegate::slotFullScreenClicked()
 {
-    showDocumentInFullScreenRequested(urlForIndex(d->mIndexUnderCursor));
+    emit showDocumentInFullScreenRequested(urlForIndex(d->mIndexUnderCursor));
 }
 
 void PreviewItemDelegate::slotToggleSelectionClicked()
@@ -957,7 +957,7 @@ void PreviewItemDelegate::updateEditorGeometry(QWidget* widget, const QStyleOpti
         return;
     }
     QString text = index.data().toString();
-    int textWidth = edit->fontMetrics().width("  " + text + "  ");
+    int textWidth = edit->fontMetrics().width(QStringLiteral("  ") + text + QStringLiteral("  "));
     QRect textRect(
         option.rect.left() + (option.rect.width() - textWidth) / 2,
         option.rect.top() + 2 * ITEM_MARGIN + d->mThumbnailSize.height(),
